import http.client
import json
import pandas as pd
import datetime
import time
import os

def post_backfill(api_key, data_mode, start_date, end_date):
    # Dict to formatted request body (To be converted to JSON String Payload)

    request_body = {
        "APIToken": "2cfddfbfb565f846395a3dc98c2c59da658a25a6d5b835196c10059d1dbe240c",
        "start": "1506484800000",
        "end": "1506830399999",
        "type": "json",
        "replies": True,
        "displayMode": "volume",
        "ranker": "Posts",
        "includes": {
            "parentCompanies": [],
            "genres": [],
            "shows": [],
            "posts": [],
            "postTypes": [],
            "creators": [],
            "creatorTypes": [],
            "withTags": [],
            "messageTags": [],
            "brandedContent": [],
            "dayOfWeek": []
        },
        "excludes": {
            "parentCompanies": [],
            "genres": [],
            "shows": [],
            "posts": [],
            "postTypes": [],
            "creators": [],
            "creatorTypes": [],
            "withTags": [],
            "messageTags": [],
            "brandedContent": [],
            "dayOfWeek": []
        }
    }

    day = 86400000  # Duration of day in epoch time
    week = day * 7
    year = day * 365

    increment_type = day  # What increment to pull data e.g. daily, weekly

    start = (str(start_date) + ' 00:00:00')
    end = (str(end_date) + ' 23:59:59')

    # Set pattern for epoch converssion
    pattern = '%m/%d/%y %H:%M:%S'

    # Convert start and end strings back to epoch time in miliseconds
    epoch_start = int(time.mktime(time.strptime(start, pattern))) * 1000
    epoch_end = int(time.mktime(time.strptime(end, pattern))) * 1000

    time_increment = int(round((epoch_end - epoch_start) / increment_type, 0))

    # set API call params
    allowed_calls = 250
    mins_allowed = 60

    # Calculate API calls per second
    api_call_freq = (mins_allowed * 60) / allowed_calls

    # API Request

    connection = http.client.HTTPConnection("api.test.canvs.social")

    headers = {'content-type': "application/json"}

    request_body['APIToken'] = api_key

    # Create empty dataframe for loading in api results
    api_result_df = pd.DataFrame()

    # Initialized parameters to feed into for loop
    api_query_start = epoch_start
    api_query_end = epoch_start + (increment_type - 1)

    # Set api start
    api_start_time = time.time()

    # Iterate by time increment across duration of start and end date
    for i in range(time_increment):

        # Modify request body start and end date
        request_body['start'] = api_query_start
        request_body['end'] = api_query_end

        # Query API with modified payload
        payload = json.dumps(request_body)
        connection.request("POST", "/explore/canvs-watch", payload, headers)

        result = connection.getresponse()
        raw_data = json.loads(result.read())

        # Navigate to the portion of the dictionary to be converted to DF
        show_data = raw_data['data']['posts']

        # Convert dict to df
        df = pd.DataFrame(show_data)
        df.drop(df.index[0], inplace=True)  # drop average column from results
        df['timestamp_epoch'] = api_query_start
        df['date_est'] = time.strftime('%m/%d/%y',
                                       time.localtime((api_query_start / 1000)))  # strftime takes arg in seconds

        # Append new data to master dataframe
        api_result_df = api_result_df.append(df)

        # Update start and end date for next iteration
        api_query_start = api_query_start + increment_type
        api_query_end = api_query_start + (increment_type - 1)

        # Print out results to test time logic
        print(i, request_body['start'], request_body['end'], "calls per second", api_call_freq)

        api_end_time = float(api_call_freq - (time.time() - api_start_time))

        if api_end_time > 0:
            time.sleep(api_end_time)

        api_start_time = time.time()

    api_result_df.reset_index(inplace=True)
    api_result_df.drop(labels='index', inplace=True, axis=1)

    # convert dict of emotion results to emotional dataframe
    elem = api_result_df.loc[0, "emotionsDrilldownVolume"]

    emo_df = pd.DataFrame([[list(elem.values())[0] for elem in api_result_df.loc[i, "emotionsDrilldownVolume"]] for i in
                           api_result_df.index])

    emotions = ['love', 'crazy', 'enjoy', 'excited', 'funny', 'hate', 'beautiful', 'happy', 'congrats', 'afraid',
                'dislike', \
                'sad', 'angry', 'annoying', 'disappointed', 'boring', 'cried', 'unsure', 'idiot', 'awkward',
                'brilliant', \
                'brutal', 'weird', 'interesting', 'ugly', 'badass', 'looks_good', 'sentimental', 'nervous',
                'disgusting', \
                'jealous', 'lucky', 'worried', 'thrilling', 'embarrassing', 'fake', 'goosebumps', 'supportive',
                'not_funny', \
                'fml', 'not_scary', 'rage', 'mixed']

    emo_df.columns = emotions

    complete_df = pd.concat([api_result_df.drop(['emotionsDrilldownVolume'], axis=1), emo_df], axis=1)

    complete_df['query_date'] = datetime.datetime.now().timestamp()

    # replace spaces with underscores and lowercase all columns
    complete_df.columns = complete_df.columns.str.replace(' ', '_')
    complete_df.columns = map(str.lower, complete_df.columns)

    # Format name of csv
    csv_name = 'watch_post_backfill_' + start_date + '_' + end_date + '.csv'

    csv_name = csv_name.replace('/', '.')

    # Drop file in data pull folder. Create folder if it does not currently exist
    outdir = 'api_exports/watch'
    if not os.path.exists(outdir):
        os.makedirs(outdir)

    fullname = os.path.join(outdir, csv_name)

    # Print resuts to CSV
    complete_df.to_csv(fullname, index=False, encoding='utf-8-sig')

def series_backfill(api_key, data_mode, start_date, end_date):
    # Dict to formatted request body (To be converted to JSON String Payload)

    request_body = {
        "APIToken": "2cfddfbfb565f846395a3dc98c2c59da658a25a6d5b835196c10059d1dbe240c",
        "start": "1506484800000",
        "end": "1506830399999",
        "type": "json",
        "replies": True,
        "displayMode": "volume",
        "ranker": "Shows, Parent Company",
        "includes": {
            "parentCompanies": [],
            "genres": [],
            "shows": [],
            "posts": [],
            "postTypes": [],
            "creators": [],
            "creatorTypes": [],
            "withTags": [],
            "messageTags": [],
            "brandedContent": [],
            "dayOfWeek": []
        },
        "excludes": {
            "parentCompanies": [],
            "genres": [],
            "shows": [],
            "posts": [],
            "postTypes": [],
            "creators": [],
            "creatorTypes": [],
            "withTags": [],
            "messageTags": [],
            "brandedContent": [],
            "dayOfWeek": []
        }
    }

    day = 86400000  # Duration of day in epoch time
    week = day * 7
    year = day * 365

    increment_type = day  # What increment to pull data e.g. daily, weekly

    start = (str(start_date) + ' 00:00:00')
    end = (str(end_date) + ' 23:59:59')

    # Set pattern for epoch converssion
    pattern = '%m/%d/%y %H:%M:%S'

    # Convert start and end strings back to epoch time in miliseconds
    epoch_start = int(time.mktime(time.strptime(start, pattern))) * 1000
    epoch_end = int(time.mktime(time.strptime(end, pattern))) * 1000

    time_increment = int(round((epoch_end - epoch_start) / increment_type, 0))

    # set API call params
    allowed_calls = 250
    mins_allowed = 60

    # Calculate API calls per second
    api_call_freq = (mins_allowed * 60) / allowed_calls

    # API Request
    connection = http.client.HTTPConnection("api.test.canvs.social")

    headers = {'content-type': "application/json"}

    request_body['APIToken'] = api_key

    # Create empty dataframe for loading in api results
    api_result_df = pd.DataFrame()

    # Initialized parameters to feed into for loop
    api_query_start = epoch_start
    api_query_end = epoch_start + (increment_type - 1)

    # Set api start
    api_start_time = time.time()

    # Iterate by time increment across duration of start and end date
    for i in range(time_increment):

        # Modify request body start and end date
        request_body['start'] = api_query_start
        request_body['end'] = api_query_end

        # Query API with modified payload
        payload = json.dumps(request_body)
        connection.request("POST", "/explore/canvs-watch", payload, headers)

        result = connection.getresponse()
        raw_data = json.loads(result.read())

        # Navigate to the portion of the dictionary to be converted to DF
        show_data = raw_data['data']['shows']

        # Convert dict to df
        df = pd.DataFrame(show_data)
        df.drop(df.index[0], inplace=True)  # drop average column from results
        df['timestamp_epoch'] = api_query_start
        df['date_est'] = time.strftime('%m/%d/%y',
                                       time.localtime((api_query_start / 1000)))  # strftime takes arg in seconds

        # Append new data to master dataframe
        api_result_df = api_result_df.append(df)

        # Update start and end date for next iteration
        api_query_start = api_query_start + increment_type
        api_query_end = api_query_start + (increment_type - 1)

        # Print out results to test time logic
        print(i, request_body['start'], request_body['end'], "calls per second", api_call_freq)

        api_end_time = float(api_call_freq - (time.time() - api_start_time))

        if api_end_time > 0:
            time.sleep(api_end_time)

        api_start_time = time.time()

    api_result_df.reset_index(inplace=True)
    api_result_df.drop(labels='index', inplace=True, axis=1)

    # convert dict of emotion results to emotional dataframe
    elem = api_result_df.loc[0, "emotionsDrilldownVolume"]

    emo_df = pd.DataFrame([[list(elem.values())[0] for elem in api_result_df.loc[i, "emotionsDrilldownVolume"]] for i in
                           api_result_df.index])

    emotions = ['love', 'crazy', 'enjoy', 'excited', 'funny', 'hate', 'beautiful', 'happy', 'congrats', 'afraid',
                'dislike', \
                'sad', 'angry', 'annoying', 'disappointed', 'boring', 'cried', 'unsure', 'idiot', 'awkward',
                'brilliant', \
                'brutal', 'weird', 'interesting', 'ugly', 'badass', 'looks_good', 'sentimental', 'nervous',
                'disgusting', \
                'jealous', 'lucky', 'worried', 'thrilling', 'embarrassing', 'fake', 'goosebumps', 'supportive',
                'not_funny', \
                'fml', 'not_scary', 'rage', 'mixed']

    emo_df.columns = emotions

    complete_df = pd.concat([api_result_df.drop(['emotionsDrilldownVolume'], axis=1), emo_df], axis=1)

    complete_df['query_date'] = datetime.datetime.now().timestamp()

    # replace spaces with underscores and lowercase all columns
    complete_df.columns = complete_df.columns.str.replace(' ', '_')
    complete_df.columns = map(str.lower, complete_df.columns)

    # Format name of csv
    csv_name = 'watch_series_backfill_' + start_date + '_' + end_date + '.csv'

    csv_name = csv_name.replace('/', '.')

    # Drop file in data pull folder. Create folder if it does not currently exist
    outdir = 'api_exports/watch'
    if not os.path.exists(outdir):
        os.makedirs(outdir)

    fullname = os.path.join(outdir, csv_name)

    # Print resuts to CSV
    complete_df.to_csv(fullname, index=False, encoding='utf-8-sig')


import pandas as pd
import glob
import os
import logging

# Internal imports
# from utilities import logging_setup
#
# # initialize logging setup
# logging_setup()
#
log = logging.getLogger(__name__)


# Create a single data file from similar type files (csv or xlsx)
def consolidate_data(file_path, file_type='csv'):
    """
    :param file_path: path to a directory of similar type and similarly structured files
    :param file_type: (str) currently only supports csv
    :return: A df of all data from files in file path of designated file type
    """

    if file_type == 'csv':
        print('csv mode enabled')

    else:
        raise Exception

    files = glob.glob(os.path.join(os.path.abspath(file_path), '*.' + file_type))  # Get filepaths of all files

    print('combining {} files'.format(len(files)))

    df = pd.DataFrame()

    counter = 1

    for file_ in files:
        # TODO implement excel support when making into larger project
        file_df = pd.read_csv(file_, dtype='str')

        log.debug('loaded file {} of {}'.format(counter, len(files)))

        file_df['file_name'] = file_

        df = df.append(file_df, sort=True)

        counter = counter + 1

    df = df.reset_index(drop=True)

    print('completed building dataframe!')

    return df


import http.client
import json
import pandas as pd
import time
import os
import logging

# Internal imports
# from utilities import logging_setup

# initialize logging setup
# logging_setup()

log = logging.getLogger(__name__)


# helper function
def query_increments(start_date, end_date, query_increment=None):
    """
    :param query_increment: day (str 'day'), week (str 'week), custom epoch increment (int of epoch time in
    milliseconds, or none. None will return payload in a single api call.

    :param start_date: (Int) epoch time (ms)
    :param end_date: (int) epoch time (ms)
    :return: epoch time increment (ms) to be used as the denominator of the get_facebook_posts api requests.
    """

    day = 86400000

    if query_increment == 'day':

        return day

    elif query_increment == 'week':
        return day * 7

    elif query_increment == type(int):

        return query_increment

    else:

        return int(end_date) - int(start_date)

# Query Canvs Facebook Owned Sources api
def get_facebook_posts(api_key, fb_id, org_id, start_date, end_date, query_increment=None):
    """
    :param api_key:
    :param fb_id:
    :param org_id:
    :param start_date:
    :param end_date:
    :param request_body:
    :param query_increment:
    :return:
    """

    # Default request body
    request_body = {
        "APIToken": "",
        "collectionId": "",
        "start": "1539662400000",
        "end": "1539748800000",
        "count": 29,
        "email": "david@canvs.tv",
        "orgId": "541323e78d7688d418000041",
        "filters": {
            "replies": True,
            "emotions": [],
            "postType": [],
            "brands": [],
            "messageTags": [],
            "withTags": [],
            "datasetId": []
        },
        "includes": {
            "topics": [],
            "hashtags": [],
            "authors": []
        },
        "excludes": {
            "topics": [],
            "hashtags": [],
            "authors": []
        },
        "fromCampaign": False,
        "fromCanvsWatch": False,
        "fromFacebookTV": False,
        "type": "json"
    }

    start = (str(start_date) + ' 00:00:00')
    end = (str(end_date) + ' 23:59:59')

    # Set pattern for epoch conversion
    pattern = '%m/%d/%y %H:%M:%S'

    # Convert start and end strings back to epoch time in milliseconds
    epoch_start = int(time.mktime(time.strptime(start, pattern))) * 1000
    epoch_end = int(time.mktime(time.strptime(end, pattern))) * 1000

    increment = query_increments(start_date=epoch_start, end_date=epoch_end, query_increment=query_increment)

    time_increment = int(round((epoch_end - epoch_start) / increment, 0))  # Divide by seconds of day in epoch

    # set API call params
    allowed_calls = 250
    mins_allowed = 60

    # Calculate API calls per second
    api_call_freq = (mins_allowed * 60) / allowed_calls

    # Format API Request
    connection = http.client.HTTPConnection("api.test.canvs.social")

    headers = {'content-type': "application/json"}

    request_body['APIToken'] = api_key  # Set API key

    request_body['collectionId'] = fb_id  # Set id of owned source to export

    request_body['orgId'] = org_id  # Set org ID to determine permission levels

    # Create empty dataframe for loading in api results
    api_result_df = pd.DataFrame()

    # Initialized parameters to feed into for loop
    api_query_start = epoch_start
    api_query_end = epoch_start + (increment - 1)

    # Set api start
    api_start_time = time.time()

    # Iterate by time increment across duration of start and end date
    for i in range(time_increment):

        # Modify request body start and end date
        request_body['start'] = api_query_start
        request_body['end'] = api_query_end

        # Query API with modified payload
        payload = json.dumps(request_body)

        connection.request("POST", "/catalog-owned/extract", payload, headers)

        result = connection.getresponse()
        raw_data = json.loads(result.read())

        # Navigate to the portion of the dictionary to be converted to DF
        # Normalize to Dataframe

        try:
            flattened_data = pd.io.json.json_normalize(raw_data['data']['datasetDrilldown'])

            # Append new data to master dataframe
            api_result_df = api_result_df.append(flattened_data, sort=False)

            # Update start and end date for next iteration
            api_query_start = api_query_start + increment
            api_query_end = api_query_start + (increment - 1)

            # Print out results to test time logic
            # print('start time {}. end time{}, calls per second {}'.format(request_body['start'],
            #                                                                  request_body['end'],
            #                                                                  api_call_freq))

            print(i, request_body['start'], request_body['end'], 'calls per second', api_call_freq)

            api_result_df.reset_index(inplace=True)
            api_result_df.drop(labels='index', inplace=True, axis=1)

        except Exception as e:
            print("failed to pull fb posts. {}".format(e))
            # print("failed to pull", e)

        finally:
            api_end_time = float(api_call_freq - (time.time() - api_start_time))

            if api_end_time > 0:
                time.sleep(api_end_time)

            api_start_time = time.time()


        emotions = ['love', 'crazy', 'enjoy', 'excited', 'funny', 'hate', 'beautiful', 'happy', 'congrats', 'afraid',
                    'dislike',
                    'sad', 'angry', 'annoying', 'disappointed', 'boring', 'cried', 'unsure', 'idiot', 'awkward',
                    'brilliant',
                    'brutal', 'weird', 'interesting', 'ugly', 'badass', 'looks_good', 'sentimental', 'nervous',
                    'disgusting',
                    'jealous', 'lucky', 'worried', 'thrilling', 'embarrassing', 'fake', 'goosebumps', 'supportive',
                    'not_funny',
                    'fml', 'not_scary', 'rage', 'mixed']
        emo_df = pd.DataFrame(0, columns=emotions, index=range(len(api_result_df)))

        for i in api_result_df.index:
            all_emotions = api_result_df.loc[i, "canvsMetrics.emotionsDrilldownCount"]

            for emo in all_emotions:
                field = list(emo.keys())[0]
                value = list(emo.values())[0]
                if field in emotions:
                    emo_df.loc[i, field] = value
                else:
                    emo_df.loc[i, 'mixed'] += value

        complete_df = pd.concat([api_result_df.drop(['canvsMetrics.emotionsDrilldownCount'], axis=1), emo_df], axis=1)

        # Format name of csv
        outname = 'social_fb_posts_' + fb_id + '_' + start_date + '_' + end_date + '.csv'

        outname = outname.replace('/', '.')

        outdir = os.path.abspath('api_exports/social')

        if not os.path.exists(outdir):
            os.makedirs(outdir)

        fullname = os.path.join(outdir, outname)

        # print page results to csv
        complete_df.to_csv(fullname, index=False)

        print('Successfully created {} file.'.format(fullname))

    return complete_df

# Send a list of page IDs and query all pages for the time range
def get_page_collection(api_key, org_id, start_date, end_date, fb_pages, query_increment=None):
    """
    :param api_key:
    :param org_id:
    :param start_date:
    :param end_date:
    :param fb_pages: (list) list of fb page IDs
    :param query_increment:
    :return:
    """
    final_result = pd.DataFrame()

    for i in fb_pages:

        try:
            # Pull pages one by one
            result = get_facebook_posts(api_key=api_key, fb_id=i, org_id=org_id,
                                        start_date=start_date, end_date=end_date, query_increment=query_increment)
        except Exception as e:
            print('A page could not be loaded {} raised {}'.format(i, e))
            # print('A page could not be loaded {} raised {}'.format(i, e))

        # Print each page's result to a new file

        # Format name of csv
        outname = 'social_fb_posts_' + i + '_' + start_date + '_' + end_date + '.csv'

        outname = outname.replace('/', '.')

        outdir = os.path.abspath('api_exports/social')

        if not os.path.exists(outdir):
            os.makedirs(outdir)

        fullname = os.path.join(outdir, outname)

        # print page results to csv
        result.to_csv(fullname, index=False)

        print('Successfully created {} file.'.format(outname))

        # Append values to master file
        final_result = final_result.append(result, sort=False)

    return final_result



from canvs_toolbox.general import consolidate_data
import pandas as pd
import itertools
from scipy.spatial.distance import euclidean, pdist, squareform
import os

def audience_overlap_analysis(directory):
    df = consolidate_data(directory, file_type='csv')

    # Use file name to designate show name
    df['series_name'] = df['file_name'].apply(lambda x: os.path.basename(os.path.normpath(x))).str.replace('.csv', '')
    df.drop(columns='file_name', inplace=True)

    # Create Unique list of shows for analysis
    series_list = list(set(df['series_name']))

    # Logic to filter down to only unique users per show. Filters out dupes if added.
    master_df = pd.DataFrame()

    for i in range(len(series_list)):
        series_counter = i
        current_series = series_list[i]
        series_df = df.loc[df['series_name'] == current_series]
        filtered_df = pd.DataFrame(series_df['users'].unique())
        filtered_df['series_name'] = current_series

        master_df = master_df.append(filtered_df)

    master_df.rename(columns={0: 'users'}, inplace=True)

    audience_overlap = pd.DataFrame({'comparison': [], 'overlapping_authors': [], 'unique_authors': []})

    # Create list of all possible iterations across all possible unique shows.
    for i in range(len(series_list)):
        r = i + 1
        list_logic = list(itertools.combinations(series_list, r))

        for counter, value in enumerate(list_logic):
            compset_df = master_df.loc[master_df['series_name'].isin(list_logic[counter])]

            df_counts = compset_df['users'].value_counts()

            dupe_authors = len(df_counts[df_counts == r])
            unique_authors = len(list(set(compset_df['users'])))
            comparison = str(list_logic[counter])
            audience_overlap = audience_overlap.append({'comparison': comparison, \
                                                        'overlapping_authors': dupe_authors, \
                                                        'unique_authors': unique_authors}, ignore_index=True)

    audience_overlap['percent_overlap'] = audience_overlap.overlapping_authors / audience_overlap.unique_authors

    csv_name = 'tv_audience_overlap_' + os.path.basename(os.path.normpath(directory)) + '.csv'
    csv_name = csv_name.replace('/', '.')

    outdir = 'analytics_exports/tv'
    if not os.path.exists(outdir):
        os.makedirs(outdir)

    fullname = os.path.join(outdir, csv_name)

    audience_overlap.to_csv(fullname, index=False)

def audience_erosion_analysis(filename):
    df = pd.read_csv(filename)

    # count the number of unique episodes in a season

    episode_list = list(set(df['episode']))
    episode_counter = list(set(df['episode']))

    # perform audience loss over season episode by episode. Note, season is not taken into account. Only episodes

    data_cols = ['users', 'season', 'episode']
    data_list = []
    for episode in episode_list:
        data_list.append(df.loc[df['episode'].isin(episode_counter)].nunique())
        del episode_counter[0]

    # build dataframe with audience loss data by episode. Episode numbers are in reverse order at this point in code

    audience_erosion = pd.DataFrame(data_list, columns=data_cols)

    # Reverse episode numbers to reflect audience behaviors. Renames to number of episodes active

    audience_erosion['episodes active'] = audience_erosion['episode'].iloc[::-1].reset_index(drop=True)
    audience_erosion.drop(['episode'], axis=1, inplace=True)

    # Run share of total audience lost per episode calculation
    max_audience = audience_erosion['users'].max()
    audience_erosion['% of total audience'] = audience_erosion['users'].divide(max_audience)

    # Reorder colums before writing to csv
    reordered_cols = ['season', 'episodes active', 'users', '% of total audience']
    audience_erosion = audience_erosion[reordered_cols]

    csv_name = 'tv_audience_erosion_' + os.path.basename(os.path.normpath(filename))
    csv_name = csv_name.replace('/', '.')

    outdir = 'analytics_exports/tv'
    if not os.path.exists(outdir):
        os.makedirs(outdir)

    fullname = os.path.join(outdir, csv_name)

    audience_erosion.to_csv(fullname, index=False)

def similarity_func(u, v):
    return 1/(1+euclidean(u,v))

#source = direct or api
def emotional_fingerprinting_analysis(filename, format):
    if filename.split(".", 1)[1] == "csv":
        df = pd.read_csv(filename)
    elif filename.split(".", 1)[1] == "xlsx":
        df = pd.read_excel(filename, sheet_name='Programs')

        newNames = {}

        def rename(x):
            newNames[x] = str(x)[:-7].lower().replace(' ', '_')

        x = list(map(rename, list(df.columns[13:56])))
        df.rename(columns=newNames, inplace=True)
        df = df[1:]
    else:
        print("invalid source type -- please set to either 'direct' or 'api'")

    emotionCols = ['love', 'crazy', 'enjoy', 'excited', 'funny', 'hate', 'beautiful', 'happy', 'congrats', 'afraid',
                   'dislike',
                   'sad', 'angry', 'annoying', 'disappointed', 'boring', 'cried', 'unsure', 'idiot', 'awkward',
                   'brilliant',
                   'brutal', 'weird', 'interesting', 'ugly', 'badass', 'looks_good', 'sentimental', 'nervous',
                   'disgusting',
                   'jealous', 'lucky', 'worried', 'thrilling', 'embarrassing', 'fake', 'goosebumps', 'supportive',
                   'not_funny',
                   'fml', 'not_scary', 'rage', 'mixed']

    if 'pagename' in df.columns:
        nameCol = ['pagename']
    elif 'programtitle' in df.columns:
        nameCol = ['programtitle']
    elif 'postMetadata.postMessage' in df.columns:
        nameCol = ['postMetadata.postMessage']
    else:
        nameCol = ['Program Title']

    DF_var = df[emotionCols + nameCol].set_index(nameCol)

    # Runs Euclidian function
    dists = pdist(DF_var, similarity_func)

    # Creates similarity matrix
    DF_euclid = pd.DataFrame(squareform(dists), columns=DF_var.index, index=DF_var.index)

    outdir = 'analytics_exports/tv'
    if not os.path.exists(outdir):
        os.makedirs(outdir)

    if format == 'stacked':
        euclid_stacked = DF_euclid.stack()

        euclid_stacked = pd.DataFrame(euclid_stacked, columns=['value'])
        euclid_stacked.index.names = ['asset', 'comparison']

        DF_euclid = euclid_stacked
        csv_name = 'emotional_fingerprint_stacked_' + os.path.basename(os.path.normpath(filename)) + '.csv'
    elif format == 'matrix':
        csv_name = 'emotional_fingerprint_matrix_' + os.path.basename(os.path.normpath(filename)) + '.csv'
    else:
        print("invalid format type -- please set to either 'stacked' or 'matrix'")

    csv_name = csv_name.replace('/', '.')
    fullname = os.path.join(outdir, csv_name)
    DF_euclid.to_csv(fullname, index=True)






